[−]Struct rust_htslib::bam::record::CigarString
A CIGAR string. This type wraps around a Vec<Cigar>.
Example
use rust_htslib::bam::record::{Cigar, CigarString}; let cigar = CigarString(vec![Cigar::Match(100), Cigar::SoftClip(10)]); // access by index assert_eq!(cigar[0], Cigar::Match(100)); // format into classical string representation assert_eq!(format!("{}", cigar), "100M10S"); // iterate for op in &cigar { println!("{}", op); }
Methods
impl CigarString[src]
pub fn into_view(self, pos: i32) -> CigarStringView[src]
Create a CigarStringView from this CigarString at position pos
pub fn from_alignment(alignment: &Alignment, hard_clip: bool) -> Self[src]
Calculate the bam cigar from the alignment struct. x is the target string
and y is the reference. hard_clip controls how unaligned read bases are encoded in the
cigar string. Set to true to use the hard clip (H) code, or false to use soft clip
(S) code. See the SAM spec for more details.
pub fn from_bytes(text: &[u8]) -> Result<Self, CigarError>[src]
Create a CigarString from given bytes.
pub fn from_str(text: &str) -> Result<Self, CigarError>[src]
Create a CigarString from given str.
pub fn to_string(&self) -> String[src]
impl<'a> CigarString[src]