[][src]Module rust_htslib::bcf::synced::pairing

This module contains bitmask constants for SyncedReader.

Constants

ANY

Any combination of alleles can be returned by bcf_sr_next_line().

BOTH

SNPS | INDELS.

BOTH_REF

SNPS | INDELS | SNP_REF | INDEL_REF.

EXACT

Require the exact same set of alleles in all files.

INDELS

The same as above, but with indels.

INDEL_REF

Allow REF-only records with indels.

SNPS

Allow different alleles, as long as they all are SNPs.

SNP_REF

Allow REF-only records with SNPs.

SOME

At least some of multiallelic ALTs must match. Implied by all the others with the exception of EXACT.