pub trait Read: Sized { // Required methods fn read(&mut self, record: &mut Vec<u8>) -> Result<bool>; fn records(&mut self) -> Records<'_, Self> ⓘ; fn header(&self) -> &Vec<String>; }
A trait for a Tabix reader with a read method.
Read next line into the given Vec<u8> (i.e., ASCII string).
Vec<u8>
Use this method in combination with a single allocated record to avoid the reallocations occurring with the iterator.
record
Ok(true) if record was read, Ok(false) if no more record in file
Iterator over the lines/records of the seeked region.
Note that, while being convenient, this is less efficient than pre-allocating a Vec<u8> and reading into it with the read() method, since every iteration involves the allocation of a new Vec<u8>.
read()
Return the text headers, split by line.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".