Function rust_htslib::utils::copy_memory
source · Expand description
Copies data from src to dst
TODO remove once stable in standard library.
Panics if the length of dst is less than the length of src.
Copies data from src to dst
TODO remove once stable in standard library.
Panics if the length of dst is less than the length of src.